@@ -231,6 +231,6 @@ def _add_origin_name_to_nodes(nodes: Dict[str, NodeResponse]):
 
 
 DATASET_DATA = {'datasetVersion': {'metadata': {'setup': {'preprocess': {'training_length': 0, 'validation_length': 0},
-                'inputs': [], 'metadata': [], 'outputs': [], 'decoders': [], 'prediction_types': [],
+                'inputs': [], 'metadata': [], 'outputs': [], 'visualizers': [], 'prediction_types': [],
                 'custom_loss_names': []}}},
                 'type': 'dataset'}
